@@ -196,48 +196,45 @@ class cgjobmgr_job
    */
   public function set_status($status,$message = null)
   {
-    switch( $status )
-      {
-      case self::STATUS_FINISHED:
-	$this->_finished_at = time();
-	if( $this->_recur_interval > 0 ) {
-	  $this->_start_at = $this->_finished_at + $this->_recur_interval * 60;
-	  // its a recurring task, mark all of the tasks as incomplete now.
-	  foreach( $this->_tasks as &$onetask ) {
-	    $onetask->set_status(cgjobmgr_task::STATUS_NONE);
-	  }
+    switch( $status ) {
+    case self::STATUS_FINISHED:
+      $this->_finished_at = time();
+      if( $this->_recur_interval > 0 ) {
+	$this->_start_at = $this->_finished_at + $this->_recur_interval * 60;
+	// its a recurring task, mark all of the tasks as incomplete now.
+	foreach( $this->_tasks as &$onetask ) {
+	  $onetask->set_status(cgjobmgr_task::STATUS_NONE);
 	}
-	$runcount = $this->get_persistent_value('__RUNCOUNT__',0);
-	$runcount++;
-	$this->set_persistent_value('__RUNCOUNT__',$runcount);
-	$this->_status = $status;
-	break;
-
-      case self::STATUS_UNSTARTED:
-	$this->_started_at = null;
-	$this->_finished_at = null;
-	$this->_status = $status;
-	break;
-	
-      case self::STATUS_INPROGRESS:
-	$this->_started_at = time();
-	$this->_status = $status;
-	break;
-
-      case self::STATUS_COMPLETING:
-      case self::STATUS_ABORTED:
-      case self::STATUS_ERROR:
-	if( $message ) {
-	  $this->set_persistent_value('__MESSAGE__',$message);
-	}
-	$this->_finished_at = time();
-      case self::STATUS_PAUSED:
-	$this->_status = $status;
-	break;
-
-      default:
-	throw new CGJobMgrException('Attempt to set job to invalid status: '.$status);
       }
+      $runcount = $this->get_persistent_value('__RUNCOUNT__',0);
+      $runcount++;
+      $this->set_persistent_value('__RUNCOUNT__',$runcount);
+      $this->_status = $status;
+      break;
+
+    case self::STATUS_UNSTARTED:
+      $this->_started_at = null;
+      $this->_finished_at = null;
+      $this->_status = $status;
+      break;
+
+    case self::STATUS_INPROGRESS:
+      $this->_started_at = time();
+      $this->_status = $status;
+      break;
+
+    case self::STATUS_COMPLETING:
+    case self::STATUS_ABORTED:
+    case self::STATUS_ERROR:
+      if( $message ) $this->set_persistent_value('__MESSAGE__',$message);
+      $this->_finished_at = time();
+    case self::STATUS_PAUSED:
+      $this->_status = $status;
+      break;
+
+    default:
+      throw new CGJobMgrException('Attempt to set job to invalid status: '.$status);
+    }
   }
 
 
@@ -366,12 +363,10 @@ class cgjobmgr_job
    */
   public function &get_current_task()
   {
-    for( $i = 0; $i < count($this->_tasks); $i++ )
-      {
-	if( $this->_tasks[$i]->get_status() == cgjobmgr_task::STATUS_COMPLETE ) continue;
-	
-	return $this->_tasks[$i];
-      }
+    for( $i = 0; $i < count($this->_tasks); $i++ ) {
+      if( $this->_tasks[$i]->get_status() == cgjobmgr_task::STATUS_COMPLETE ) continue;
+      return $this->_tasks[$i];
+    }
     $res = null;
     return $res;
   }
@@ -435,40 +430,38 @@ class cgjobmgr_job
   public static function &load_from_data($row)
   {
     $obj = new cgjobmgr_job();
-    foreach( $row as $key => $value )
-      {
-	switch( $key )
-	  {
-	  case 'id':
-	  case 'name':
-	  case 'owner':
-	  case 'priority':
-	  case 'status':
-	  case 'recur_interval':
-	  case 'start_at':
-	  case 'started_at':
-	  case 'finished_at':
-	  case 'locked':
-	    $fld = '_'.$key;
-	    $obj->$fld = $value;
-	    break;
-	    
-	  case 'assoc':
-	    $obj->_persistent = unserialize($value);
-	    break;
-	    
-	  case 'tasks':
-	    $obj->_tasks = unserialize($value);
-	    break;
-	    
-	  case 'created':
-	  case 'modified':
-	    break;
+    foreach( $row as $key => $value ) {
+      switch( $key ) {
+      case 'id':
+      case 'name':
+      case 'owner':
+      case 'priority':
+      case 'status':
+      case 'recur_interval':
+      case 'start_at':
+      case 'started_at':
+      case 'finished_at':
+      case 'locked':
+	$fld = '_'.$key;
+	$obj->$fld = $value;
+	break;
 
-	  default:
-	    throw new CGJobMgrException('Unknown field '.$key.' in row data');
-	  }
-      } // foreach
+      case 'assoc':
+	$obj->_persistent = unserialize($value);
+	break;
+
+      case 'tasks':
+	$obj->_tasks = unserialize($value);
+	break;
+
+      case 'created':
+      case 'modified':
+	break;
+
+      default:
+	throw new CGJobMgrException('Unknown field '.$key.' in row data');
+      }
+    } // foreach
 
     return $obj;
   }
@@ -478,9 +471,7 @@ class cgjobmgr_job
     $db = cmsms()->GetDb();
     $query = 'SELECT * FROM '.cms_db_prefix().'module_cgjobmgr WHERE id = ?';
     $row = $db->GetRow($query,array($jobid));
-    if( is_array($row) ) {
-      return self::load_from_data($row);
-    }
+    if( is_array($row) ) return self::load_from_data($row);
 
     $res = null;
     return $res;
@@ -499,9 +490,7 @@ class cgjobmgr_job
 			      serialize($this->_tasks),
 			      $this->_recur_interval,$this->_start_at,
 			      $this->_started_at,$this->_finished_at));
-    if( !$dbr ) {
-      throw new CGJobMgrException('Error Inserting job record ');
-    }
+    if( !$dbr ) throw new CGJobMgrException('Error Inserting job record ');
 
     $this->_id = $db->Insert_Id();
     audit($this->_id,'CGJobMgr','New job created: '.$this->_name.' with priority '.$this->_priority);
@@ -526,9 +515,7 @@ class cgjobmgr_job
 			      serialize($this->_tasks),$this->_recur_interval,$this->_start_at,
 			      $this->_started_at,$this->_finished_at,
 			      $this->_id));
-    if( !$dbr ) {
-      throw new CGJobMgrException('Error Updating job record ');
-    }
+    if( !$dbr ) throw new CGJobMgrException('Error Updating job record ');
   }
 
 
@@ -537,9 +524,7 @@ class cgjobmgr_job
    */
   public function delete()
   {
-    if( $this->_id <= 0 ) {
-      throw new CGJobMgrException('Cannot delete a job with no id.');
-    }
+    if( $this->_id <= 0 ) throw new CGJobMgrException('Cannot delete a job with no id.');
 
     $db = cmsms()->GetDb();
     $query = 'DELETE FROM '.cms_db_prefix().'module_cgjobmgr WHERE id = ?';
@@ -549,9 +534,8 @@ class cgjobmgr_job
     $id = $this->name;
     $this->_id = null;
 
-
     $mod = cms_utils::get_module('CGJobMgr');
-    audit($id,$mod->GetName(),'Deleted Job: '.$name);
+    audit('',$mod->GetName(),'Deleted Job: '.$name);
     $mod->SendEvent('JobDeleted',array('job'=>$this));
   }
 
@@ -577,14 +561,12 @@ class cgjobmgr_job
    */
   public function lock()
   {
-    if( !$this->_id )
-      throw new CGJobMgrException('Attempt to lock a job that has not been saved');
+    if( !$this->_id ) throw new CGJobMgrException('Attempt to lock a job that has not been saved');
 
     $db = cmsms()->GetDb();
     $query = 'UPDATE '.cms_db_prefix().'module_cgjobmgr SET locked = 1 WHERE id = ?';
     $dbr = $db->Execute($query,array($this->_id));
-    if( $db->ErrorMsg() )
-      throw new CGJobMgrException('Problem locking job '.$this->_id);
+    if( $db->ErrorMsg() ) throw new CGJobMgrException('Problem locking job '.$this->_id);
   }
 
 
@@ -593,19 +575,16 @@ class cgjobmgr_job
    */
   public function unlock()
   {
-    if( !$this->_id ) {
-      throw new CGJobMgrException('Attempt to unlock a job that has not been saved');
-    }
+    if( !$this->_id ) throw new CGJobMgrException('Attempt to unlock a job that has not been saved');
 
     $db = cmsms()->GetDb();
     $query = 'UPDATE '.cms_db_prefix().'module_cgjobmgr SET locked = 0 WHERE id = ?';
     $dbr = $db->Execute($query,array($this->_id));
-    if( $db->ErrorMsg() )
-      throw new CGJobMgrException('Problem unlocking job '.$this->_id);
+    if( $db->ErrorMsg() ) throw new CGJobMgrException('Problem unlocking job '.$this->_id);
   }
 } // end of class
 
 #
 # EOF
 #
-?>
+?>
\ No newline at end of file
