@@ -196,6 +196,32 @@ abstract class cgjobmgr_task
     $interval = max(1,$interval);
     return $interval;
   }
+
+  /**
+   * Get CGJobMgr run interval.
+   *
+   * @return integer the run interval (in minutes), or null.
+   */
+  public function get_escalation_interval()
+  {
+    $mod = cms_utils::get_module('CGJobMgr');
+    $interval = (int)$mod->GetPreference('escallation_intervallimit',10);
+    $interval = min(100,max(1,$interval));
+    return $interval;
+  }
+
+  /**
+   * Get CGJobMgr number of autotask iterations.
+   *
+   * @return integer the number of iterations before waiting for the next cron interval.
+   */
+  public function get_max_iterations()
+  {
+    $mod = cms_utils::get_module('CGJobMgr');
+    $interval = (int)$mod->GetPreference('max_autotask_iterations',10);
+    $interval = max(1,$interval);
+    return $interval;
+  }
 } // end of class
 
 #
